LocationType

Enum LocationType 

#[non_exhaustive]
pub enum LocationType {
Show 59 variants Aircraft, Airport, Arena, Automobile, Bank, Bar, Bicycle, Bus, BusStation, Cafe, Campground, CareFacility, Classroom, Club, Construction, ConventionCenter, DetachedUnit, FireStation, Government, Hospital, Hotel, Industrial, LandmarkAddress, Library, Motorcycle, MunicipalGarage, Museum, Office, Other, Outdoors, Parking, PhoneBox, PlaceOfWorship, PostOffice, Prison, Public, PublicTransport, Residence, Restaurant, School, ShoppingArea, Stadium, Store, Street, Theater, TollBooth, TownHall, Train, TrainStation, Truck, Underway, Unknown, UtilityBox, Warehouse, WasteTransferFacility, Water, WaterFacility, Watercraft, YouthCamp,
}
A location type from the IANA Location Types Registry.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


Aircraft

A device used for flight (airplane, helicopter, glider, balloon, etc.).

Source: RFC 4589.



Airport

A place from which aircraft operate (airport, heliport).

Source: RFC 4589.



Arena

Enclosed area used for sports events.

Source: RFC 4589.



Automobile

An automotive vehicle designed for passenger transportation.

Source: RFC 4589.



Bank

Business establishment for financial services.

Source: RFC 4589.



Bar

A bar or saloon.

Source: RFC 4589.



Bicycle

A two-wheeled pedal-propelled vehicle.

Source: RFC 4589.



Bus

A large motor vehicle designed to carry passengers.

Source: RFC 4589.



BusStation

Terminal that serves bus passengers (bus depot, bus terminal).

Source: RFC 4589.



Cafe

A small informal establishment serving refreshments; coffee shop.

Source: RFC 4589.



Campground

An area used for camping, often with facilities for tents or RVs.

Source: NH Division of Emergency Services and Communications.



CareFacility

A facility providing care services (nursing home, assisted living).

Source: NH Division of Emergency Services and Communications.



Classroom

Academic classroom or lecture hall.

Source: RFC 4589.



Club

Dance club, nightclub, or discotheque.

Source: RFC 4589.



Construction

Construction site.

Source: RFC 4589.



ConventionCenter

Convention center or exhibition hall.

Source: RFC 4589.



DetachedUnit

A building or housing unit that is not attached to other buildings.

Source: NH Division of Emergency Services and Communications.



FireStation

A facility housing firefighting equipment and personnel.

Source: NH Division of Emergency Services and Communications.



Government

Government building (legislative, executive, judicial, police, military).

Source: RFC 4589.



Hospital

Hospital, hospice, medical clinic, mental institution, or doctor’s office.

Source: RFC 4589.



Hotel

Hotel, motel, inn, or other lodging establishment.

Source: RFC 4589.



Industrial

Industrial setting (manufacturing floor, power plant).

Source: RFC 4589.



LandmarkAddress

A location identified by a landmark or notable address.

Source: NH Division of Emergency Services and Communications.



Library

Library or other public place for literary and artistic materials.

Source: RFC 4589.



Motorcycle

A two-wheeled automotive vehicle, including a scooter.

Source: RFC 4589.



MunicipalGarage

A garage owned or operated by a municipality.

Source: NH Division of Emergency Services and Communications.



Museum

A building housing collections of artifacts or specimens.

Source: NENA-STA-004.1.1-2025, NG9-1-1 CLDXF-US.



Office

Business setting, such as an office.

Source: RFC 4589.



Other

A place without a registered place type representation.

Source: RFC 4589.



Outdoors

Outside a building, in the open air (park, city streets).

Source: RFC 4589.



Parking

A parking lot or parking garage.

Source: RFC 4589.



PhoneBox

A public telephone booth or kiosk.

Source: NH Division of Emergency Services and Communications.



PlaceOfWorship

A religious site (church, chapel, mosque, shrine, synagogue, temple).

Source: RFC 4589.



PostOffice

A post office or mail facility.

Source: NH Division of Emergency Services and Communications.



Prison

Correctional institution (prison, penitentiary, jail, brig).

Source: RFC 4589.



Public

Public area (shopping mall, street, park, public building, conveyance).

Source: RFC 4589.



PublicTransport

Any form of public transport (aircraft, bus, train, ship).

Source: RFC 4589.



Residence

A private or residential setting.

Source: RFC 4589.



Restaurant

Restaurant, coffee shop, or other public dining establishment.

Source: RFC 4589.



School

School or university property.

Source: RFC 4589.



ShoppingArea

Shopping mall or area with stores accessible by common passageways.

Source: RFC 4589.



Stadium

Large structure for sports events, including a racetrack.

Source: RFC 4589.



Store

Place where merchandise is offered for sale; a shop.

Source: RFC 4589.



Street

A public thoroughfare (avenue, street, alley, lane, road, sidewalk).

Source: RFC 4589.



Theater

Theater, auditorium, movie theater, or similar presentation facility.

Source: RFC 4589.



TollBooth

A booth or station for collecting tolls.

Source: NH Division of Emergency Services and Communications.



TownHall

A building housing local government offices.

Source: NH Division of Emergency Services and Communications.



Train

Train, monorail, maglev, cable car, or similar conveyance.

Source: RFC 4589.



TrainStation

Terminal where trains load or unload passengers or goods.

Source: RFC 4589.



Truck

An automotive vehicle for hauling goods rather than people.

Source: RFC 4589.



Underway

In a land-, water-, or aircraft that is in motion.

Source: RFC 4589.



Unknown

The type of place is unknown.

Source: RFC 4589.



UtilityBox

A utility box or cabinet housing utility equipment.

Source: NH Division of Emergency Services and Communications.



Warehouse

Place for storing goods (storehouse, self-storage facility).

Source: RFC 4589.



WasteTransferFacility

A facility for processing or transferring waste materials.

Source: NH Division of Emergency Services and Communications.



Water

In, on, or above bodies of water (ocean, lake, river, canal).

Source: RFC 4589.



WaterFacility

A facility for water treatment or distribution.

Source: NH Division of Emergency Services and Communications.



Watercraft

A vessel for travel on water (boat, ship).

Source: RFC 4589.



YouthCamp

A camp providing programs and activities for youth.

Source: NH Division of Emergency Services and Communications.