Module string

Module string 

String data model types.

Structs

LanguageTag
A BCP 47 language tag (RFC 5646).
Uid
A globally unique identifier.
UidBuf
Uri
A URI string (RFC 3986).
UriBuf

Enums

InvalidUidError
An error indicating that a string is not a valid UID.
InvalidUriError
An error indicating that a string is not a valid URI.
LanguageTagParseError
Re-export of the error type from the language-tags crate. Errors returned by LanguageTag parsing