Uri

Struct Uri 

pub struct Uri(/* private fields */);
A URI string (RFC 3986).

Invariants

  1. The underlying string is not empty.
  2. The string contains a colon separating the scheme from the rest.
  3. The scheme starts with a letter and contains only letters, digits, +, -, or ..

Implementations

Source

impl Uri

pub fn new(input: &str) -> Result<&Self, InvalidUriError>

Source

impl Uri

pub const fn as_str(&self) -> &str

Source

impl Uri

pub fn scheme(&self) -> &str

Returns the scheme portion of the URI (before the first colon).