#[repr(u8)]pub enum Month {
Jan = 1,
Feb = 2,
Mar = 3,
Apr = 4,
May = 5,
Jun = 6,
Jul = 7,
Aug = 8,
Sep = 9,
Oct = 10,
Nov = 11,
Dec = 12,
}Expand description
One of the twelve Gregorian months.
Variants
Implementations
Sourceimpl Month
impl Month
Sourcepub const fn new(value: u8) -> Result<Self, InvalidMonthError>
pub const fn new(value: u8) -> Result<Self, InvalidMonthError>
Creates a Month from a 1-based month number, returning an error if out of range.
Sourcepub const fn number(self) -> NonZero<u8>
pub const fn number(self) -> NonZero<u8>
Returns the month number of self, which lies in the range 1..=12.
Sourcepub fn iter() -> impl ExactSizeIterator<Item = Month>
pub fn iter() -> impl ExactSizeIterator<Item = Month>
Returns an iterator over all twelve months, starting from January.