pub struct Date { /* private fields */ }Expand description
An ISO 8601 date.
Implementations
Sourceimpl Date
impl Date
Sourcepub const fn new(
year: Year,
month: Month,
day: Day,
) -> Result<Self, ImpossibleDateError>
pub const fn new( year: Year, month: Month, day: Day, ) -> Result<Self, ImpossibleDateError>
Creates a new date, returning an error if the day is out of range for the given month and year.
Sourcepub const fn maximum_day(year: Year, month: Month) -> Day
pub const fn maximum_day(year: Year, month: Month) -> Day
Returns the maximum day of month in year, based on the table given in RFC 3339 5.7.