pub struct DateTime<M> {
pub date: Date,
pub time: Time,
pub marker: M,
}Expand description
An ISO 8601 datetime with the timezone marker M (RFC 3339 5.6).
This type makes no guarantees about the relationship between its fields, and in particular does
not guarantee that the time field represents a time that actually occurred on the date
represented by the date field; that is, it does not encode any information about leap
seconds.
Fields
date: DateThe date component.
time: TimeThe time component.
marker: MThe timezone marker.