Date, time, and string primitive types for calendar data.
This crate provides the foundational types shared by both iCalendar (RFC 5545) and JSCalendar (RFC 8984) implementations. It includes:
- Date and time types (
time):Year,Month,Day,Hour,Minute,Second,Date,Time, andDateTimewith compile-time timezone markers. - Duration types (
duration):DurationandSignedDurationfollowing RFC 8984 1.4.6–7. - String types (
string): validatedUidandUrinewtypes. - Primitives (
primitive):Signfor positive/negative values. - CSS colors (
css):Css3Colorenum for the W3C CSS3 color names. - Token sets (
set):Tokenfor extensible enum values, and IANA registry types (LinkRelation,LocationType).