pub enum Token<T, S> {
Known(T),
Unknown(S),
}Expand description
A token which may be a statically known value of type T or else an unknown value of type
S.
The principal use of this type is to allow finite enums to be extended with arbitrary values, most commonly some unknown string which is permissible but statically unknowable.
Variants
Implementations
Sourceimpl<T, S> Token<T, S>
impl<T, S> Token<T, S>
Sourcepub fn try_from_str<'a>(
s: &'a str,
) -> Result<Self, <&'a str as TryInto<S>>::Error>
pub fn try_from_str<'a>( s: &'a str, ) -> Result<Self, <&'a str as TryInto<S>>::Error>
Like FromStr, but uses a fallible conversion for the unknown variant.
Sourcepub fn map_unknown<U>(self, f: impl FnOnce(S) -> U) -> Token<T, U>
pub fn map_unknown<U>(self, f: impl FnOnce(S) -> U) -> Token<T, U>
Maps the unknown value of a Token, leaving known values unchanged.