pub struct Uri(/* private fields */);Expand description
A URI string (RFC 3986).
Invariants
- The underlying string is not empty.
- The string contains a colon separating the scheme from the rest.
- The scheme starts with a letter and contains only letters, digits,
+,-, or..